diff --git a/game/client/src/main/java/net/minecraft/client/gui/TooltipElement.java b/game/client/src/main/java/net/minecraft/client/gui/TooltipElement.java
index 8f77ea0b0..564048e0b 100644
--- a/game/client/src/main/java/net/minecraft/client/gui/TooltipElement.java
+++ b/game/client/src/main/java/net/minecraft/client/gui/TooltipElement.java
@@ -273,9 +273,12 @@ public class TooltipElement extends Gui
         stylesIdList.clear();
 
 
+        final List<TexturePack> packs = new ArrayList<>();
+        packs.add(packList.getDefaultTexturePack());
+        packs.addAll(packList.selectedPacks);
         final Collection<String> styleIds = new ArrayList<>();
-        for (int i = packList.selectedPacks.size() - 1; i >= 0; i--) {
-            final TexturePack pack = packList.selectedPacks.get(i);
+        for (int i = packs.size() - 1; i >= 0; i--) {
+            final TexturePack pack = packs.get(i);
             try (final InputStream stylesStream = pack.getResourceAsStream("/assets/minecraft/textures/gui/sprites/tooltip/styles.json")) {
                 if (stylesStream != null) {
                     final JsonObject stylesListObject = JsonParser.parseReader(new InputStreamReader(stylesStream)).getAsJsonObject();
diff --git a/game/client/src/main/java/net/minecraft/client/gui/keyboard/keys/CursorKey.java b/game/client/src/main/java/net/minecraft/client/gui/keyboard/keys/CursorKey.java
index 7a52a755a..e889ac411 100644
--- a/game/client/src/main/java/net/minecraft/client/gui/keyboard/keys/CursorKey.java
+++ b/game/client/src/main/java/net/minecraft/client/gui/keyboard/keys/CursorKey.java
@@ -27,7 +27,7 @@ public class CursorKey extends Key{
     }
 
     public static class Serializer implements JsonSerializer<CursorKey>, JsonDeserializer<CursorKey> {
-        public static final int DEFAULT_WIDTH = 25;
+        public static final int DEFAULT_WIDTH = 18;
         public static final int DEFAULT_HEIGHT = 18;
 
         public static final String DEFAULT_TEXTURE_NEXT_UP = "minecraft:gui/widgets/keyboard/key_page_next/up";
diff --git a/game/client/src/main/resources/assets/minecraft/textures/gui/sprites/tooltip/metallic/border.png b/game/client/src/main/resources/assets/minecraft/textures/gui/sprites/tooltip/metallic/border.png
new file mode 100644
index 000000000..1d8ee96b8
Binary files /dev/null and b/game/client/src/main/resources/assets/minecraft/textures/gui/sprites/tooltip/metallic/border.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/gui/sprites/tooltip/metallic/border.png.mcmeta b/game/client/src/main/resources/assets/minecraft/textures/gui/sprites/tooltip/metallic/border.png.mcmeta
new file mode 100644
index 000000000..709e14b16
--- /dev/null
+++ b/game/client/src/main/resources/assets/minecraft/textures/gui/sprites/tooltip/metallic/border.png.mcmeta
@@ -0,0 +1,15 @@
+{
+    "gui": {
+        "scaling": {
+            "type": "nine_slice",
+            "width": 26,
+            "height": 26,
+            "border": {
+                "top": 7,
+                "left": 9,
+                "right": 3,
+                "bottom": 4
+            }
+        }
+    }
+}
\ No newline at end of file
diff --git a/game/client/src/main/resources/assets/minecraft/textures/gui/sprites/tooltip/metallic/inner.png b/game/client/src/main/resources/assets/minecraft/textures/gui/sprites/tooltip/metallic/inner.png
new file mode 100644
index 000000000..42fc57e6c
Binary files /dev/null and b/game/client/src/main/resources/assets/minecraft/textures/gui/sprites/tooltip/metallic/inner.png differ
diff --git a/game/client/src/main/resources/assets/minecraft/textures/gui/sprites/tooltip/metallic/inner.png.mcmeta b/game/client/src/main/resources/assets/minecraft/textures/gui/sprites/tooltip/metallic/inner.png.mcmeta
new file mode 100644
index 000000000..fe6ff48cf
--- /dev/null
+++ b/game/client/src/main/resources/assets/minecraft/textures/gui/sprites/tooltip/metallic/inner.png.mcmeta
@@ -0,0 +1,10 @@
+{
+    "gui": {
+        "scaling": {
+            "type": "nine_slice",
+            "width": 16,
+            "height": 16,
+            "border": 6
+        }
+    }
+}
\ No newline at end of file
diff --git a/game/client/src/main/resources/assets/minecraft/textures/gui/sprites/tooltip/metallic/properties.json b/game/client/src/main/resources/assets/minecraft/textures/gui/sprites/tooltip/metallic/properties.json
new file mode 100644
index 000000000..2ffb4353e
--- /dev/null
+++ b/game/client/src/main/resources/assets/minecraft/textures/gui/sprites/tooltip/metallic/properties.json
@@ -0,0 +1,3 @@
+{
+    "padding": 2
+}
\ No newline at end of file
diff --git a/game/client/src/main/resources/assets/minecraft/textures/gui/sprites/tooltip/styles.json b/game/client/src/main/resources/assets/minecraft/textures/gui/sprites/tooltip/styles.json
index 447c18010..e4cf119f0 100644
--- a/game/client/src/main/resources/assets/minecraft/textures/gui/sprites/tooltip/styles.json
+++ b/game/client/src/main/resources/assets/minecraft/textures/gui/sprites/tooltip/styles.json
@@ -7,6 +7,7 @@
         "default",
         "detailed",
         "interdimensional",
+        "metallic",
         "modern",
         "noteblock",
         "picnic",
diff --git a/game/core/src/main/java/net/minecraft/core/entity/animal/MobWolf.java b/game/core/src/main/java/net/minecraft/core/entity/animal/MobWolf.java
index c0d278226..e1018d96b 100644
--- a/game/core/src/main/java/net/minecraft/core/entity/animal/MobWolf.java
+++ b/game/core/src/main/java/net/minecraft/core/entity/animal/MobWolf.java
@@ -867,7 +867,7 @@ public class MobWolf extends MobAnimal implements IItemHolding
 
     public boolean isWolfSitting()
     {
-        return (entityData.getByte(DATA_GENERIC_FLAGS) & 1) != 0;
+        return (entityData.getByte(DATA_GENERIC_FLAGS) & MASK_SITTING) != 0;
     }
 
     public void setWolfSitting(boolean flag)
diff --git a/game/core/src/main/resources/lang/en_US/options.lang b/game/core/src/main/resources/lang/en_US/options.lang
index 228964dca..f1e88401e 100644
--- a/game/core/src/main/resources/lang/en_US/options.lang
+++ b/game/core/src/main/resources/lang/en_US/options.lang
@@ -181,6 +181,7 @@ options.screen.motion.effects=Screen Motion Effects
 
 options.tooltipStyle.default=Default
 options.tooltipStyle.modern=Modern
+options.tooltipStyle.metallic=Metallic
 options.tooltipStyle.stone=Stone
 options.tooltipStyle.planks=Planks
 options.tooltipStyle.rpg=RPG
